@@ -148,7 +148,7 @@ gtctrl@testtype <- factor("Raw", levels = tlev)
 mydata = data.frame(y = gl(2, 50), x1 = rnorm(100),
                     x2 = rnorm(100), x3 = rnorm(100))
 inp <- initVariableFrame(mydata[,c("x1", "x2", "x3"),drop = FALSE], 
-    trafo = function(data) trafo(data, numeric_trafo = rank))
+    trafo = function(data) ptrafo(data, numeric_trafo = rank))
 resp <- initVariableFrame(mydata[,"y",drop = FALSE], trafo = NULL)
 ls <- new("LearningSample", inputs = inp, responses = resp,
           weights = rep(1, inp@nobs), nobs = nrow(mydata), 
@@ -169,7 +169,7 @@ varctrl <- new("VariableControl")
 gtctrl@testtype <- factor("MonteCarlo", levels = tlev)
 gtctrl@nresample <- as.integer(19999)
 inp <- initVariableFrame(mydata[,"x1",drop = FALSE], trafo = function(data)
-    trafo(data, numeric_trafo = rank))
+    ptrafo(data, numeric_trafo = rank))
 resp <- initVariableFrame(mydata[,"y",drop = FALSE], trafo = NULL)
 ls <- new("LearningSample", inputs = inp, responses = resp,
           weights = rep(1, inp@nobs), nobs = nrow(mydata), 
